@@ -2,7 +2,7 @@ package WebService::2Captcha;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp 'croak';
 use LWP::UserAgent;
@@ -139,7 +139,7 @@ sub request {
         }
     }
 
-    print Dumper(\$res); use Data::Dumper;
+    # print Dumper(\$res); use Data::Dumper;
 
     return $res->decoded_content;
 }
